@@ -36,11 +36,14 @@ SAB :: <include|exclude> <source1, source2, ... sourceN>
 
 REL :: <include|exclude> <relation1, relation2, ... relationN>
 
+RELA :: <include|exclude> <rela1, rela2, ... relaN> (optional)
+
 For example, if we wanted to use the MSH vocabulary with only 
 the RB/RN relations, the configuration file would be:
 
 SAB :: include MSH
 REL :: include RB, RN
+RELA :: include inverse_isa, isa
 
 or 
 
@@ -212,10 +215,6 @@ if(defined $opt_socket) {
 
 $umls = UMLS::Interface->new(\%option_hash); 
 die "Unable to create UMLS::Interface object.\n" if(!$umls);
-($errCode, $errString) = $umls->getError();
-die "$errString\n" if($errCode);
-
-&errorCheck($umls);
 
 my $input  = shift;
 my $rel    = shift;
@@ -230,24 +229,15 @@ else {
     @c = $umls->getConceptList($input);
 }
 
-&errorCheck($umls);
-
 my $printFlag = 0;
 
 foreach my $cui (@c) {
 
-    if($umls->validCui($cui)) {
-	print STDERR "ERROR: The concept ($cui) is not valid.\n";
-	exit;
-    }
-
     #  make certain cui exists in this view
     if($umls->exists($cui) == 0) { next; }	
     
     my @cuis = $umls->getRelated($cui, $rel); 
     
-    &errorCheck($umls);
-    
     if($#cuis < 0) {
 	print "No CUIs are associated with $term ($cui) given the relation ($rel).\n";
     }
@@ -264,14 +254,7 @@ foreach my $cui (@c) {
 if(! ($printFlag) ) {
     print "No CUIs are associated with $input given the relation ($rel).\n";
 }
-	    
-sub errorCheck
-{
-    my $obj = shift;
-    ($errCode, $errString) = $obj->getError();
-    print STDERR "$errString\n" if($errCode);
-    exit if($errCode > 1);
-}
+
 
 
 ##############################################################################
@@ -321,7 +304,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: getRelated.pl,v 1.10 2010/05/11 20:04:46 btmcinnes Exp $';
+    print '$Id: getRelated.pl,v 1.11 2010/05/24 17:57:16 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
